"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.whereClauseNewLine = void 0;
const META = {
    name: 'where-clause-new-line',
    type: 'select'
};
exports.whereClauseNewLine = {
    meta: META,
    create: (context) => {
        if (!context.node.where) {
            return;
        }
        function findInvalidClause(expr) {
            if (expr.left.location.start.line === expr.right.location.start.line && expr.left.type === 'binary_expr') {
                return expr.left;
            }
            if (expr.right.type === 'binary_expr') {
                return findInvalidClause(expr.right);
            }
            return null;
        }
        const invalidClause = findInvalidClause(context.node.where.expression);
        if (invalidClause) {
            return {
                message: 'Multiple where clause must go on a new line.',
                location: invalidClause.location,
                rulename: META.name,
                errorLevel: context.config.level
            };
        }
    }
};
//# sourceMappingURL=whereClauseNewLine.js.map